Re: [PATCH/RFC 0/6] commit caching
- From
Duy Nguyen <pclouds@gmail.com>
- Date
- Jan 30, 2013, 03:31 UTC
- Message-ID
- <CACsJy8BE3LdxbZzdQXuvEJop23KnnLbCTgPos9CywKV7EY2q9g@mail.gmail.com>
- In-Reply-To
- <20130129091434.GA6975@sigill.intra.peff.net>
On Tue, Jan 29, 2013 at 4:14 PM, Jeff King <peff@peff.net> wrote:
Show 7 quoted lines
> The timings from this one are roughly similar to what I posted earlier. > Unlike the earlier version, this one keeps the data for a single commit > together for better cache locality (though I don't think it made a big > difference in my tests, since my cold-cache timing test ends up touching > every commit anyway). The short of it is that for an extra 31M of disk > space (~4%), I get a warm-cache speedup for "git rev-list --all" of > ~4.2s to ~0.66s.
Some data point on caching 1-parent vs 2-parent commits on webkit repo, 26k commits. With your changes (caching 2-parent commits), the .commits file takes 2241600 bytes. "rev-list --all --quiet":
0.06user 0.00system 0:00.08elapsed 95%CPU (0avgtext+0avgdata 26288maxresident)k 0inputs+0outputs (0major+2094minor)pagefaults 0swaps
With caching 1-parent commits only, the .commits file takes 1707900 bytes (30% less), the same rev-list command:
0.07user 0.00system 0:00.07elapsed 96%CPU (0avgtext+0avgdata 24144maxresident)k 0inputs+0outputs (0major+1960minor)pagefaults 0swaps
Compared to the timing without caching at all:
0.72user 0.02system 0:00.76elapsed 98%CPU (0avgtext+0avgdata 108976maxresident)k 0inputs+0outputs (0major+7272minor)pagefaults 0swaps
The performance loss in 1-parent case is not significant while disk saving is (although it'll be less impressive after you do Shawn's suggestion not storing SHA-1 directly)
-- Duy